@@ -80,7 +80,7 @@ class Weights:
             raise ValueError("length of class_names must be equal to num_classes")
 
     @staticmethod
-    def _validate_input(d) -> None:
+    def _validate_input(d: dict, config_path: Path) -> None:
         """Raise error if invalid input."""
 
         if not isinstance(d, dict):
@@ -165,7 +165,7 @@ class Weights:
         if len(d["class_names"]) != d["num_classes"]:
             raise ValueError("mismatch between length of class_names and num_classes.")
         if "file" in d.keys():
-            file = Path(path).parent / d["file"]
+            file = Path(config_path).parent / d["file"]
             file = file.resolve()
             if not file.exists():
                 raise FileNotFoundError(f"'file' not found: {file}")
@@ -176,7 +176,7 @@ class Weights:
 
         with open(path) as f:
             d = yaml.safe_load(f)
-        cls._validate_input(d)
+        cls._validate_input(d, config_path=Path(path))
 
         transform = PatchClassification(
             resize_size=d["transform"]["resize_size"],
@@ -217,6 +217,7 @@ class Weights:
             raise RuntimeError("cannot find weights")
 
         model.load_state_dict(state_dict, strict=True)
+        model.eval()
         return model
 
     def get_sha256_of_weights(self) -> str:
@@ -278,10 +279,10 @@ def get_model_weights(architecture: str, name: str) -> Weights:
     try:
         return _known_model_weights[key]
     except KeyError:
+        pairs = " | ".join(" / ".join(p) for p in list_all_models_and_weights())
         raise ModelWeightsNotFound(
-            f"model weights are not found for architecture '{architecture}' and "
-            f"weights name '{name}'. Available models are"
-            f"{list_all_models_and_weights()}."
+            f"Invalid model-weight pair: '{architecture}' and '{name}'. Available"
+            f" models/weight pairs are {pairs}."
         )
 
 
